"use strict";
const Generator = require("yeoman-generator");
const path = require("path");
const git = require("simple-git/promise");
const fs = require("fs-extra");
const constants_1 = require("../../constants");
/**
 * Yeoman generator responsible for cloning the git repo associated with the
 * git url passed as gitRepoUrl option.
 */
class CreateGenerator extends Generator {
    constructor(args, opts) {
        super(args, opts);
        if (!opts.name) {
            this.env.error(new Error("missing required option: name"));
        }
        if (!opts.gitRepoUrl) {
            this.env.error(new Error("missing required option: gitRepo"));
        }
        this.gitRepo = opts.gitRepoUrl;
        this.pjson = { name: opts.name };
        this.destPath = path.resolve(opts.name);
    }
    async writing() {
        // Clone the sample apps repo
        await git().clone(this.gitRepo, this.destPath);
        // Remove the .git directory so that the user can start their git 
        // history from scratch
        process.chdir(this.destPath);
        const gitPath = path.join(this.destPath, '.git');
        fs.removeSync(gitPath);
        // Add the user provided details to the app's package.json
        const pjsonPath = path.join(this.destPath, './package.json');
        this.fs.extendJSON(pjsonPath, this.pjson);
    }
    end() {
        console.log(constants_1.MESSAGE_PROJECT_CREATED, this.pjson.name, this.destPath);
    }
}
module.exports = CreateGenerator;
