"use strict";
const command_1 = require("@oclif/command");
const yeoman_environment_1 = require("yeoman-environment");
const constants_1 = require("./constants");
/**
 * CreateCommerceApp command allows creating a sample commerce app with name of
 * the app being the argument passed to the command. It also makes available
 * a help menu which lists the way to use the command and the options available
 * with it.
 *
 */
class CreateCommerceApp extends command_1.Command {
    /**
     * Parses the arguments passed to the command and creates an app in the
     * current directory with the argument passed for appName.
     *
     */
    run() {
        const { args } = this.parse(CreateCommerceApp);
        const appName = args.appName;
        const env = yeoman_environment_1.createEnv();
        env.register(require.resolve('./generators/app'), 'CreateGenerator');
        // converting the callback into a promise
        return new Promise((resolve, reject) => {
            env.run('CreateGenerator', {
                name: appName,
                gitRepoUrl: constants_1.SAMPLE_APPS_GIT_REPO_URL,
                force: true
            }, (err) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    }
}
CreateCommerceApp.description = 'Creates a new Headless Commerce Application';
CreateCommerceApp.flags = {
    help: command_1.flags.help({
        char: 'h'
    }),
};
CreateCommerceApp.args = [
    {
        name: 'appName',
        required: true,
    }
];
module.exports = CreateCommerceApp;
